# geoserverx
A GeoServer REST API client influenced by HTTPX

-----------

`geoserverx` allows `Sync`, `Async` as well as `CLI` Capabilities to talk to your GeoServer REST APIs which makes it ideal to be used in software development project which relies on content of GeoServer. 

Here is a simplistic view of how geoserverx works under the hood
![architecture](/docs/assets/images/arch.png "architecture")





## Contribution guide

### Feature/Bug request
Please open new issue if you want to report any bug or send feature request

### Running on local
`geoserverx` is built with [poetry](https://python-poetry.org/) and it uses following dependencies and dev-dependencies

![layout](/docs/assets/images/layout.png "layout")